clear all			//clear workspace
capture log close	//force any previously open logs to close
version 14.2          //specify version for reproducible results  
set more off        //turn off the --more--prompts in output


******************************************************************************
*	Survival Analysis in Stata: StatLab Workshop Do-File
*	Author: Alex Jakubow 												
*	File: SurvivalAnalysis.do
*	Created: 01 March 201											
******************************************************************************

******************************************************************************
*	DESCRIPTION	
*	
*	This code accompanies the lecture slides for this workshop.  Covered
*	topics include: data wrangling for survival data, setting datasets for
*	use with the suite of st commands, non-parametric analysis, semi-
*	parametric analysis and diagnostics, and fully parametric analysis.
*	
******************************************************************************

******************************************************************************
*	EXECUTION NOTES
*
*	The code is self-contained and should run as-is, although user should 
*	change file location in line 6.
*
******************************************************************************

******************************************************************************
*	OTHER NOTES
*	
*	Datasets Used: 
*
*	Quick Index:
*		Part I: 	Formatting Survival Data for Stata
*		Part II: 	Setting the Data with stset
*		Part III:  	Non-Parametric Analysis
*		Part IV:	Semi-Parametric Regressions
*		Part V:		Semi-Parametric Diagnostics
*		Part VI:	Parametric Regressions
*		
******************************************************************************



******************************************************************************
*** PART I: FORMATTING SURVIVAL DATA FOR STATA
******************************************************************************

*** Example 1: Converting Long-Form Snapshot Data ***
 	/* Snapshot datasets generally contain two types of variables:
		1.	Enduring or Characteristic variables: State characteristics 
			that are valid for longer than an instant (or at
			least we are comfortable in treating them as such).  A subject's
			gender, age rounded to years, and blood pressure at time of 
			hospitalization are examples.

		2.  Instantaneous of Event variables: These variables state events that
			occurred at a particular instant in time.  Examples couple be 
			having a heart attack, going bankrupt, the outbreak of a civil war,
			etc.

		We are going to initialize a long-form dataset segment with the 
		following variables:
			id: 		subject ID
			date:	 	entry date
			rectype: 	record or event type with the following definitions:
						1: subject enrollment
						2: subject checkup
						9: subject failure
			x: 			a continuous independent variable
			xbin: 		a binary independent variable

		x and xbin are assumed to be enduring variables.  rectype is an event 
		variable because it tells us--among other things--whether the subject
		failed.
 	*/


	* Initialize dataset *
	input id str10 date rectype x xbin
		2 20jan2000 1 2 0
		2 22jan2000 2 . 1
		2 24jan2000 2 . 0
		2 25jan2000 9 . .
	end

	* Convert date *
	gen temp = date(date, "DMY") // convert string to date
	drop date                    // drop  and replace date 
	rename temp date             
	format date %td              // reformat date
	
	
	* Briefly inspect the dataset *
	list
	summarize

	* Use snapspan to convert record pairs into time-span records *
	snapspan id date rectype, generate(date0) replace
	rename date date1
	order date0 date1, after(id)      // reorder date columns
	
	* Inspect newly-snapped data *
	list
	summarize 
		/* 	Note that snapspan neither automatically carries down enduring 
			variable values from previous records nor sets our analysis time (t)
			for us.  The nifty commands stfill and stset can 
			respectively do these tasks for us, but more on this later....
		*/
		
		
*** Example 2: Converting Wide-Form Snapshot Data ***
	/* 	The previous example was for long-form snapshot data, where each row
		corresponded to a single record/event and we had multiple obs (rows)
		per subject.  This example uses wide-form data, where each row 
		represents one subject and distinct events are listed as additional
		variables (columns)
			
		We need to first reshape the data from wide-format to long-format
		using the RESHAPE command.  Then we can use snapspan as before.
	*/
		
	* Load in the dataset *
	use "http://www.stata-press.com/data/cggm3/wide1", clear

	* Describe the dataset *
	describe
	list
	
	* Reshape *
	reshape long date event x, i(id)
	list, noobs sepby(id)
	drop if missing(date) //not all subjects have 4 entries so drop if missing
		/* 	
			Note: snapspan will complain if the data contain records without 
			dates.
		*/
		
	* Snapspan *
	snapspan id date event, gen(date0) replace
	


******************************************************************************
*** PART II: SETTING THE DATA WITH stset 
******************************************************************************

*** Example Data on Hip Fractures --------------------------------------------
	* Load and Inspect Dataset *
	use "http://www.stata-press.com/data/cggm3/hip", clear
	describe
	summarize
		/*
			A lot of missing values on age and protect.  As it happens,
			this is because the data entry folks were lazy and only put
			in these values for the first observation for each subject
			in the dataset.  Let's examine this now.  We'll fix it later.
		*/
	sort id time0
	list if inlist(id, 9, 10)

	
	* Perform Initial stset *
	stset time1, id(id) time0(time0) failure(fracture)
	
	
	* Verification Pass 1: Listing *
	list id time0 time1 frac _t0 _t _d _st if id <3, ///
		sepby(id)  //check at beginning
	list id time0 time1 frac _t0 _t _d _st if inlist(id, 16, 17, 18), ///
		sepby(id)  //check at middle					    	
	list id time0 time1 frac _t0 _t _d _st if id >= 47, ///
		sepby(id)  //check at end
		
		/*
			Everything appears to be in order.
		*/
	
	
	* Verification Pass 2: stdescribe
	stdescribe
		
		/*
			Lines 1 and 2 report the number of subjects and the total
			number of records.  48 subjects; 106 records -> ~2 records/subject
			
			Lines 3 and 4 report that everyone entered at time = 0; average
			exit time was 15.5 months; min and max exit times were 1 and 39,
			respectively.  
			Note:	15.5 is NOT the same as the average survival time, because
					some of our data are censored
					
			Lines 5 and 6 tell us that three subjects have gaps that are 
			each exactly three months long.  This seems suspicious (time
			gaps are rarely identical like this)
			
		*/
		
	sort id _t0 _t  //sort  by id, start time, end time
	qui by id: gen gap = 1 if _t0 != _t[_n-1] & _n>1
		/*
			If there are no gaps between consecutive observations, the ending
			time (_t) of the first record should equal the start time (_t0)
			of the next record.
			
			We generate an indicator that flags gaps (i.e., when the start
			and end times of adjacent records are NOT the same)
		*/
	list id if gap == 1  //get list of subjects with gaps
	list id time0 time1 _t0 _t if inlist(id, 18, 30 ,33)
		/*
			While initially odd, it does appear that everything is in order.
			We just happened to have three observations with the same exact
			gap time.
			
			Lets return to the rest of the stdescribe command; I re-execute
			it here for convenience
		*/
		
	stdescribe			
		/*
			Line 7 tells us that all subjects were are at risk of failure for
			a total of 714 months.  stdescribe calculates this by taking the 
			length of the interval for each record and then summing these
			lengths conditional on _st == 1
			
			Line 8 reports that there were 31 failures (hip fractures) in our
			dataset.  The minimum is 0, which indicates that we have censored
			observations, and the maximum is 1, which means that we are 
			dealing with single failure-per-subject data (i.e., no multiple
			failures).
		*/
		
		
	* Verification Pass 3: stvary *
	capture drop gap //drop gap indicator
	stvary
		/*
			stvary tells us the extent to which:
				1. variable values vary over our subjects
				2. variable values are missing
				
			protect and age are constant (protect is the treatment condition
			and age is the subject's age at the time he/she enrolled in the
			study), while calcium levels vary within subjects.
			
			We also notice that there are lots of missing values for age
			and protect.  This is because this information was only provided
			for a subject's first record.  These will appear as missing if
			a subject has multiple time records in the dataset/
		*/
		
	
	* Data Fixes with streset and stvary *
	streset, past future 
		/*
			past future expands stset sample to include all records on all
			relevant subjects (since we want to correctly fill in age and
			protect for all records in the dataset.
			
			streset doesn't change anything, but this is only because already
			stset the data to include all records
		*/
		
	stfill age protect, forward //fill forward age and protect w/in each subj.
	streset						//reset the data
	
	stvary //re-inspect missings
	
save hip2, replace


******************************************************************************
*** PART III: NON-PARAMETRIC ANALYSIS
******************************************************************************

*** Kaplan-Meier Estimate for On-Slide Example -------------------------------
	* Input Dataset	*
	clear 
	input id time failed
		1 2 1
		2 4 1
		3 4 1
		4 5 0 
		5 7 1 
		6 8 0 
	end
	
	* Set Data *
	stset time, fail(failed)
	
	* Calculate Kaplan-Meier Estimate *
	sts list
		/*
			Beg. Total: Number of subjects at risk at each t
			Fail:		Number of failures at each t
			Net Lost:	Calculates # of censorings - # of entries at each t
						> 0: more lost from censoring than added via entry
						< 0: more added via entry than lost via censoring
		*/

		
*** Kaplan-Meier Estimate for Hip Fracture Data ------------------------------
	* Load Dataset *
		use "http://www.stata-press.com/data/cggm3/hip2", clear
		
	* Calculate Kaplan-Meier Estimates *
	sts list
	sts list, at(5) //snapshot at 5 equally-spaced survival times
	sts list, by(protect) compare //compare control vs. treatment group
	
	* Graphing the KM Estimate *
	sts graph  //default graph of overall survivor function
	sts graph, censored(number) //indicate times and number of censorings
	
	sts graph, by(protect) //survivor curves by treatment status
	sts graph, by(protect) ///
		risktable(, order (1 "Control" 2 "Treatment") failevents) ///
		legend(label(1 "Control") label(2 "Treatment"))
		
		/*
			This last command inserts a risk table at the bottom of the
			graph, whereby the number of subjects at risk over time are
			tabulated by treatment status
			
			sts graph is a very powerful and flexible graphing command.
			Type "help sts graph" to learn more	
		*/
		
		
******************************************************************************
*** PART IV: SEMI-PARAMETRIC ANALYSIS
******************************************************************************		

*** Cox Proportional Hazards Models Using Hip Fracture Data ------------------	
	* Baseline Models *
	stcox protect 
		/*
			Results are exponentiated individual coefficients that we
			interpret in the form of hazard ratios:
			
			A subject wearing the device faces a hazard rate that is only
			12.9% of the hazard facing a subject from the control group
		*/
	stcox protect, nohr
		/*
			Same model, but this time the results are un-exponentiated 
			coefficients
		*/
			

	* Post-Estimation Options for Baseline Cumulative Hazard *
	qui stcox protect
		predict H0, basechazard  //option for baseline cumulative hazard
		line H0 _t, connect(J) sort	 //plot baseline cumulative hazard
		/*
			The plot of cumulative hazard appears to be increasing and at
			an increasing rate --> the hazard itself, should also be increasing
			(the hazard is the derivative of the cumulative hazard)
		*/

		gen H1 = H0 * .1290 
		label var H0 H0
		line H1 H0 _t, connect(J J) sort  //compare baseline cumulative hazards
		/*
			We generate cumulative baseline hazard for treatment group by
			multiplying baseline cumulate hazard by coefficient (i.e.,
			the hazard ratio) from the model
		*/


	* Post-Estimation Options for Survivor Function *
		predict S0, basesurv
		line S0 _t, c(J) sort  //plot baseline survivor function

		gen S1 = S0^(0.0129)
		label var S0 S0
		line S1 S0 _t, c(J J) sort
		/*
			We exponentiate the survivor function by the treatment coefficient
			from the model to plot the survivor function for all individuals
			in the treatment group
		*/

	* Estimating the Baseline Hazard *
		/*
			We can also obtain an estimate of the unmodeled baseline hazard
			function by applying a kernel-smoothing function to the derivative
			of the baseline cumulative function, which is = 0 except for
			at failure times (where it is undefined).

			We can use the stcurve function to achieve this.
		*/
		qui stcox protect
		stcurve, hazard at(protect=0)

		stcurve, hazard at1(protect=0) at2(protect=1) ///
			kernel(gaussian) width(4)  //compare treatment v. control


******************************************************************************
*** PART V: SEMI-PARAMETRIC MODEL DIAGNOSTICS
******************************************************************************		

*** Proper Model Specification -----------------------------------------------
	* Re-estimation Tests *
	stcox protect age
	linktest
		/*
			Link test takes the linear predictor, then reestimates a Cox model
			using the linear predictor and the square of the linear predictor
			as covariates.  In a well-specified model, the coefficient
			of the square of the linear predictor should not be significantly
			different from zero.

			The link test is equivalent to running the following:
		*/
	stcox protect age
	predict s, xb 
	stcox s c.s#c.s

		/*
			Another approach is to reestimate the original Cox model and 
			include an interaction between each covariate and some
			measure of analysis time

			We can use the	tvc() and texp() suboptions of the 
			stcox command to make this process more efficient
		*/
		
	stcox protect age, tvc(age protect) texp(_t)
		test [tvc]
	stcox protect age, tvc(age protect) texp(ln(_t))  //interact with log of _t
		test [tvc]


	* Schoenfeld Residuals *
	stcox protect age
		estat phtest, detail //provides variable-by-variable and global test
		estat phtest, plot(age) //plot residuals by _t for a given covariate


	* Graphical Methods *
		/*
			For discrete covariates, we can also compare a transformed plot
			of the the Kaplan-Meier estimate of the survivor function (y-axis)
			against the log of analysis time (x-axis) for each level of the 
			covariate in question.

			If the variable is properly specified, the plot lines for each of
			the covariate's discrete values should be roughly parallel.

		*/
		stphplot, by(protect)
		stphplot, strata(protect) adjust(age) //effects conditioned on age
		/*
			Stata fits a Cox model on the adjust() variables (since the
			KM estimate doesn't use covariates) and treats strata()
			as a stratification variable.

			This allows the baseline hazard to be different for different
			values of protect
		*/

		stcoxkm, by(protect)
		/*
			This method compares the survivor functions of the KM estimate
			(which makes no assumptions about PH) against those generated
			from a Cox model (which does) by protect.  We are looking for
			roughly similar lines between the KM and Cox plot for each
			level of protect
		*/


*** Determining Functional Form -----------------------------------------------
	* New Dataset *
		/*
			We now consider data a different medical dataset studying
			the effect of an experimental treatment on 150 children diagnosed
			with Reye's syndrome (rare disease that can cause brain swelling
			and liver inflammation, typically affecting children < 15 who
			are recovering from an upper respiratory illness---e.g., chicken
			pox or flu)

			The dataset contains the following variables:
			id: subject number
			days: elapsed days between treatment and death or censoring
			dead: 1 if death, 0 if censoring
			treat: 1 if experimental treatment; 0 if standard treatment
			age: age in years
			sex: 1 is female; 0 is male?
			ftliver: presence of fatty liver disease (1 = yes; 0 = no)
			ammonia: blood ammonia levels
			sgot: blood serum levels
		*/		

		use "http://www.stata-press.com/data/cggm3/reyes", clear
		describe
		list id days dead treat age sex ftliver ammonia sgot in 1/6, noobs sep(0)

	
	* Set the Data *
	stset days, id(id) failure(dead)

	
	* Baseline Model *
	stcox treat, efron  //ties handled using efron method (just for variety)
		/*
			Suppose we want to include additional covariates for elevated
			ammonia and serum levels, along with the presence of fatty
			liver disease.  

			What is the best functional form to use for
			each covariate?
		*/


	stcox, efron estimate 	//Step 1: Estimate Null Model
	predict mg, mgale		//Step 2: Extract martingale residuals
	lowess mg ammonia		//Step 3: Plot residuals against each covariate	
		/*
			We might want to log-transform ammonia since the graph 
			is not linear at lower levels of ammonia
		*/
		gen lamm = ln(ammonia)


	* Model with Ammonia Added *
	stcox treat lamm, efron noshow
		/*
			Increased levels of blood ammonia are associated with a
			greater hazard of dying.

			More importantly, notice that the effect of the treatment is
			now significantly associated with a lower hazard of dying 
			(significant at the 10% level).
			
			This suggests that, on average, patients with lower levels
			of blood ammonia happened to end up in the control group.

			A simple ttest of mean blood ammonia levels between groups
			confirms this:
		*/
		ttest ammonia, by(treat) unequal

	
	* Transformation for Interpretation *
		/*
			Re-centering and/or re-scaling variables frequently eases
			our interpretation of key survival functions, such as the
			cumulative baseline hazard rate.  Such changes do not
			affect parameter coefficients.

			With this in mind, we mean-center blood serum levels
			so that the baseline hazard rate now corresponds to
			treat == 0, lamm == 0, ftliver == 0, and the mean
			value of blood serum.
		*/
		qui summarize sgot
		display "Mean of sgot: " r(mean)
		replace sgot = sgot - r(mean)

	* Fit Final Model *
	stcox treat lamm sgot ftliver, efron
		/*
			With controls added, the experimental treatment reduces
			risk of death by nearly 50%.
		*/


	* Option 2: Automated-Adjustment via multivariable fractional polynomials *
	mfp, adjust(ammonia:no, sgot:no): ///
		stcox treat ammonia sgot ftliver, efron
		/*	
			Results are the same, just that the mfp prefix creates regression
			results displayed in the log-hazard (coefficient) metric

			See help mfp for more
		*/


*** Goodness of Fit -----------------------------------------------------------
		/*
			We can investigate model fit by plotting an estimate of the 
			cumulative hazard function against Cox-Snell residuals.  If
			the model was a perfect, the two lines should directly overlap.

			Here, we will uses the Reyes dataset and compare the results of
			two models.  The first uses treatment status and ammonia levels
			as covariates, while the second substitutes in the logged values
			of ammonia.
		*/


	* Reload Dataset *
	use http://www.stata-press.com/data/cggm3/reyes, clear
	*use reyes.dta, clear //if no Internet connection

	* Model 1: Regular Ammonia *
	stcox treat ammonia, efron  //execute model
	predict cs, csnell 			//extract Cox-Snell Residuals

	stset cs, fail(dead) 		//stset data using residuals as time variables

	sts generate H = na 		//generate Nelson-Aalen cumulative haz. function
	line H cs cs, sort ytitle("") ///
		legend(cols(1))  		//plot (specify cs twice to get 45-deg. ref line)
		/*
			Result: Not the greatest fit.  Let's retry with Model 2
		*/

	* Model 2: Logged Ammonia *
	use "http://www.stata-press.com/data/cggm3/reyes", clear
	gen lamm = ln(ammonia)

	stcox treat lamm, efron
	predict cs, csnell 	
	stset cs, fail(dead)
	sts gen H = na
	line H cs cs, sort ytitle("") legend(cols(1))
		/*
			Result: Better model fit using log of ammonia
		*/


*** Outlier Diagnostics  ------------------------------------------------------	
	/*
		We can detect the presence of influential observations by engaging in
		leverage analysis using DFBETAs.  Conceptually, we compare the estimated
		coefficient for the full model against the coefficient produced by a
		model re-estimated for n-1 observations after removing the ith
		observation.  

		This process is theoretically repeated for all observations	in the model.

		Since this would technically require us to run stcox n + 1 times, we 
		instead approximate this different using the efficient score residuals.
		
		Specifically, DFBETA works by taking the product of the efficient score
		residuals by the variance-covariance matrix for an estimated coefficient.
	*/

	* Reload and Modify Dataset *
	use "http://www.stata-press.com/data/cggm3/reyes", clear
	gen lamm = ln(ammonia)
	qui summarize sgot
	replace sgot = sgot - r(mean)

	* Model and Residuals*
	qui stcox treat lamm sgot ftliver, efron
		predict dfb*, dfbeta //creates dfb1, dfb2, dfb3, dfb4
							 //each corresponds to four covariates in the model


	* Graph Residuals Against Time to Identify Influential Observations *
	scatter dfb3 _t, yline(0) mlabel(id) msymbol(i)  //look at subject 69
	scatter dfb4 _t, yline(0) mlabel(id) msymbol(i)  //look at subject 116
		/*
			If subject 116 were removed, the coefficient on ftliver would
			increase by approximately 0.22.  Alternatively, it would increase
			the hazard ratio for ftliver by a factor of 0.8 (exp(-0.22))
		*/


	* Aggregate Tests of Influence *
		/*
			Executing DFBETAs becomes unwieldy if a model includes a large 
			number of covariates.  Additionally, it is theoretically possible
			to have an observation that fails to exert undue influence on the
			effect of any given covariate yet still greatly influence other
			statistics---such as the estimated hazard function or general
			model fit.

			The likelihood displacement values and LMAX values are 2 such
			options.

			The likelihood displacement value calculates the difference in
			log-likelihoods between the full model and a partial model
			with observation i omitted. Larger values imply greater 
			displacement and, thus, greater influence.

			The calculation of the LMAX measure is more technical, but
			it serves a similar diagnostic function: larger values again
			indicate more influence.
		*/

	predict ld, ldisplace //likelihood displacements
	scatter ld _t, yline(0) mlabel(id) msymbol(i)  //subjects 69 & 116

	predict lmax, lmax //LMAX values
	scatter lmax _t, yline(0) mlabel(id) msymbol(i) //subjects 116, 235, 19

	* Inspect Offending Values (DO NOT AUTOMATICALLY DROP FROM ANALYSIS) *
	list treat ammonia ftliver sgot _t _d if id ==116
		/* 
			Subject 116 belongs to control group and has fatty liver disease.
			Let's compare 116 to others in a similar situation
		*/
	sort treat ftliver _d ammonia
	list id _d _t ammonia sgot if !treat & ftliver
		/*
			Subjects 116 and 19 are only subjects from control group diagnosed
			with fatty liver disease who survived
		*/


******************************************************************************
*** PART VI: PARAMETRIC MODELS
******************************************************************************
*** Parametric Proportional Hazards Models -----------------------------------
		/*
			Let's return to the hip-fracture dataset and execute a parametric
			survival model using the exponential distribution option (In 
			effect, this assumes that the baseline hazard is constant)	
		*/
		use "http://www.stata-press.com/data/cggm3/hip2", clear

	streg protect age, dist(exponential)

		/*
			One of the primary advantages of PH parametric survival models
			is that we can quickly compare our results against a Cox model.
			If the coefficients are vastly different, we probably have selected
			a poor distributional assumption for the baseline hazard.
		*/

	stcox protect age	
		/*
			The concordance in coefficients is not great.  Recall from
			our earlier analysis using the Cox model that the estimated
			cumulative hazard seemed to be increasing at an increasing
			rate.  That said, we may be better off choosing a parameterization
			that would permit the hazard rate to grow over time.  

			Enter the Weibull model.

		*/
	streg protect age, dist(weibull)
		/*
			The estimated hazard ratio for protect is now much closer to that
			displayed in the Cox result.
		*/


*** Accelerated Failure Time Models -------------------------------------------
		streg protect age, dist(weibull) time 
		/*
			The Weibull can be estimated using either PR or AFT, so we
			report AFT results.  The coefficients are different, but this
			is merely because they are reported using a different metric.
			We could convert these coefficients back into the proportional-
			hazards metric using the following:
			HR = exp(-p_hat*beta_hat)
		*/


*** Selecting the Appropriate Parametric Models -------------------------------
		/*
			There are two statistical strategies to use in evaluating
			and selecting an appropriate parametric model.  Note, however,
			that neither of these should substitute for sound thinking
			about the underling data generating process!

			For nested models, we can use either a log ratio or 
			Wald test.  Common nested comparisons are:
				lognormal or Weibull vs. exponential
				gamma vs. Weibull or lognormal
	
			For non-nested models, we will compare Akaike information
			criteria (AIC) or Bayesian information criteria (BIC)
		*/


	* Nested Models: Wald Tests *
		/*
			Let's start with Wald tests.  We begin by fitting the gamma
			model, which is the general model to which the Weibull
			and lognormal both belong. 

			We can specifically perform a hypothesis test on the 
			parameter kappa, which equals 0 under the lognormal
			specification and equals 1 under the Weibull model.  We can
			also test for the exponential distribution, which has kappa
			equal to 1 and sigma equal 0 (this means constant rate)
		*/

	streg protect age, dist(ggamma) nolog

		*test for lognormal distribution *
		test [kappa]_b[_cons] = 0 
			/*
				We fail to reject, which means we should not preclude
				using the lognormal distribution
			*/

		* test for Weibull distribution *
		test [kappa]_b[_cons] = 1 
			/*
				We fail to reject, we should not preclude the use of the
				Weibull distribution, either
			*/

		* test for exponential distribution *
		test [kappa]_b[_cons] = 1, notest //test for kappa
		test [ln_sig]_b[_cons] = 0, accum //add test for sigma
			/*
				Reject.  The risk of hip fracture is not constant over time
				(we already knew this from earlier, too). so modeling using
				an exponential distribution is a poor choice
			*/
		

	* Nested Models: likelihood-Ratio Test *
		/*
			Now let's compare the lognormal vs. gamma using a
			likelihood ratio test
		*/
	qui streg protect age, dist(ggamma)  	//fit saturated model
		estimates store sat 				//save results
	qui streg protect age, dist(lnormal) 	//fit nested model
	lrtest sat, force						//compute LR test
		/*
			We get similar results here as we did in the Wald test above
		*/


	* Non-nested Models *
		/*
			The simplest way to compare across all distributional permutations
			is to execute each sequentially using a loop
		*/
	estimates clear
	foreach model in exponential weibull gompertz lognormal loglogistic ggamma {
		qui streg age protect, dist(`model')
		estimates store `model'
	}
	estimates stats _all //view
		/*
			We'd select the lognormal on the basis of AIC
		*/

exit
